@@ -1,7 +1,7 @@
 import uuid
 from operator import attrgetter
 
-from django import VERSION
+import django
 from django.conf import settings
 from django.contrib.contenttypes.fields import GenericRelation
 from django.contrib.contenttypes.models import ContentType
@@ -41,7 +41,7 @@ class ExtraJoinRestriction:
     def as_sql(self, compiler, connection):
         qn = compiler.quote_name_unless_alias
         if len(self.content_types) == 1:
-            extra_where = "{}.{} = %s".format(qn(self.alias), qn(self.col))
+            extra_where = f"{qn(self.alias)}.{qn(self.col)} = %s"
         else:
             extra_where = "{}.{} IN ({})".format(
                 qn(self.alias), qn(self.col), ",".join(["%s"] * len(self.content_types))
@@ -129,23 +129,14 @@ class _TaggableManager(models.Manager):
         else:
             rel_obj_attr = attrgetter("_prefetch_related_val")
 
-        if VERSION < (2, 0):
-            return (
-                qs,
-                rel_obj_attr,
-                lambda obj: obj._get_pk_val(),
-                False,
-                self.prefetch_cache_name,
-            )
-        else:
-            return (
-                qs,
-                rel_obj_attr,
-                lambda obj: obj._get_pk_val(),
-                False,
-                self.prefetch_cache_name,
-                False,
-            )
+        return (
+            qs,
+            rel_obj_attr,
+            lambda obj: obj._get_pk_val(),
+            False,
+            self.prefetch_cache_name,
+            False,
+        )
 
     def _lookup_kwargs(self):
         return self.through.lookup_kwargs(self.instance)
@@ -237,7 +228,7 @@ class _TaggableManager(models.Manager):
             # do a query.  Malcolm is very smart.
             existing = manager.filter(name__in=str_tags, **tag_kwargs)
 
-            tags_to_create = str_tags - set(t.name for t in existing)
+            tags_to_create = str_tags - {t.name for t in existing}
 
         tag_objs.update(existing)
 
@@ -600,27 +591,15 @@ class TaggableManager(RelatedField):
         linkfield1 = self.through._meta.get_field("content_object")
         linkfield2 = self.through._meta.get_field(self.m2m_reverse_field_name())
         if direct:
-            if VERSION < (2, 0):
-                join1infos = linkfield1.get_reverse_path_info()
-                join2infos = linkfield2.get_path_info()
-            else:
-                join1infos = linkfield1.get_reverse_path_info(
-                    filtered_relation=filtered_relation
-                )
-                join2infos = linkfield2.get_path_info(
-                    filtered_relation=filtered_relation
-                )
+            join1infos = linkfield1.get_reverse_path_info(
+                filtered_relation=filtered_relation
+            )
+            join2infos = linkfield2.get_path_info(filtered_relation=filtered_relation)
         else:
-            if VERSION < (2, 0):
-                join1infos = linkfield2.get_reverse_path_info()
-                join2infos = linkfield1.get_path_info()
-            else:
-                join1infos = linkfield2.get_reverse_path_info(
-                    filtered_relation=filtered_relation
-                )
-                join2infos = linkfield1.get_path_info(
-                    filtered_relation=filtered_relation
-                )
+            join1infos = linkfield2.get_reverse_path_info(
+                filtered_relation=filtered_relation
+            )
+            join2infos = linkfield1.get_path_info(filtered_relation=filtered_relation)
         pathinfos.extend(join1infos)
         pathinfos.extend(join2infos)
         return pathinfos
@@ -631,54 +610,33 @@ class TaggableManager(RelatedField):
         opts = self.through._meta
         linkfield = self.through._meta.get_field(self.m2m_reverse_field_name())
         if direct:
-            if VERSION < (2, 0):
-                join1infos = [
-                    PathInfo(
-                        self.model._meta,
-                        opts,
-                        [from_field],
-                        self.remote_field,
-                        True,
-                        False,
-                    )
-                ]
-                join2infos = linkfield.get_path_info()
-            else:
-                join1infos = [
-                    PathInfo(
-                        self.model._meta,
-                        opts,
-                        [from_field],
-                        self.remote_field,
-                        True,
-                        False,
-                        filtered_relation,
-                    )
-                ]
-                join2infos = linkfield.get_path_info(
-                    filtered_relation=filtered_relation
+            join1infos = [
+                PathInfo(
+                    self.model._meta,
+                    opts,
+                    [from_field],
+                    self.remote_field,
+                    True,
+                    False,
+                    filtered_relation,
                 )
+            ]
+            join2infos = linkfield.get_path_info(filtered_relation=filtered_relation)
         else:
-            if VERSION < (2, 0):
-                join1infos = linkfield.get_reverse_path_info()
-                join2infos = [
-                    PathInfo(opts, self.model._meta, [from_field], self, True, False)
-                ]
-            else:
-                join1infos = linkfield.get_reverse_path_info(
-                    filtered_relation=filtered_relation
+            join1infos = linkfield.get_reverse_path_info(
+                filtered_relation=filtered_relation
+            )
+            join2infos = [
+                PathInfo(
+                    opts,
+                    self.model._meta,
+                    [from_field],
+                    self,
+                    True,
+                    False,
+                    filtered_relation,
                 )
-                join2infos = [
-                    PathInfo(
-                        opts,
-                        self.model._meta,
-                        [from_field],
-                        self,
-                        True,
-                        False,
-                        filtered_relation,
-                    )
-                ]
+            ]
         pathinfos.extend(join1infos)
         pathinfos.extend(join2infos)
         return pathinfos
@@ -709,7 +667,7 @@ class TaggableManager(RelatedField):
         else:
             return (("object_id", self.model._meta.pk.column),)
 
-    def get_extra_restriction(self, where_class, alias, related_alias):
+    def _get_extra_restriction(self, alias, related_alias):
         extra_col = self.through._meta.get_field("content_type").column
         content_type_ids = [
             ContentType.objects.get_for_model(subclass).pk
@@ -717,6 +675,18 @@ class TaggableManager(RelatedField):
         ]
         return ExtraJoinRestriction(related_alias, extra_col, content_type_ids)
 
+    def _get_extra_restriction_legacy(self, where_class, alias, related_alias):
+        # this is a shim to maintain compatibility with django < 4.0
+        return self._get_extra_restriction(alias, related_alias)
+
+    # this is required to handle a change in Django 4.0
+    # https://docs.djangoproject.com/en/4.0/releases/4.0/#miscellaneous
+    # the signature of the (private) funtion was changed
+    if django.VERSION < (4, 0):
+        get_extra_restriction = _get_extra_restriction_legacy
+    else:
+        get_extra_restriction = _get_extra_restriction
+
     def get_reverse_joining_columns(self):
         return self.get_joining_columns(reverse_join=True)
 
