@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations
 
 
@@ -10,6 +7,6 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.AlterIndexTogether(
-            name="taggeditem", index_together=set([("content_type", "object_id")])
+            name="taggeditem", index_together={("content_type", "object_id")}
         )
     ]
