@@ -15,6 +15,11 @@ from taggit.models import (
 )
 
 
+# base test model
+class TestModel(models.Model):
+    tags = TaggableManager()
+
+
 # Ensure that two TaggableManagers with custom through model are allowed.
 class Through1(TaggedItemBase):
     content_object = models.ForeignKey("MultipleTags", on_delete=models.CASCADE)
@@ -403,3 +408,7 @@ class UUIDTaggedItem(GenericUUIDTaggedItemBase):
 # 	HINT: Rename field 'Tag.name', or add/change a related_name argument to the definition for field 'Name.tags'.
 class Name(models.Model):
     tags = TaggableManager(related_name="a_unique_related_name")
+
+
+class OrderedModel(models.Model):
+    tags = TaggableManager(ordering=["name"])
