@@ -1,4 +1,3 @@
-import django
 from rest_framework import serializers
 
 from taggit.serializers import TaggitSerializer, TagListSerializerField
@@ -12,5 +11,4 @@ class TestModelSerializer(TaggitSerializer, serializers.ModelSerializer):
 
     class Meta:
         model = TestModel
-        if django.VERSION >= (1, 11):
-            fields = "__all__"
+        fields = "__all__"
